@@ -44,5 +44,5 @@ fn run() -> Result<(), Box<dyn std::error::Error>> {
 #[test]
 fn verify_clap_app() {
     use clap::IntoApp;
-    Args::into_app().debug_assert()
+    Args::command().debug_assert()
 }
